==> ddd_dapr-0.1.2.crate: ddd_dapr-0.1.2/src/dapr/subscriber.rs <==
/*
 * @Author: tzw
 * @Date: 2021-11-09 02:01:16
 * @LastEditors: tzw
 * @LastEditTime: 2021-11-09 03:02:28
 */
use tonic::{transport::Server, Request, Response, Status};

use dapr::{
    appcallback::*,
    dapr::dapr::proto::runtime::v1::app_callback_server::{AppCallback, AppCallbackServer},
};

#[derive(Default)]
pub struct AppCallbackService {}

#[tonic::async_trait]
impl AppCallback for AppCallbackService {
    /// Invokes service method with InvokeRequest.
    async fn on_invoke(
        &self,
        _request: Request<InvokeRequest>,
    ) -> Result<Response<InvokeResponse>, Status> {
        Ok(Response::new(InvokeResponse::default()))
    }

    /// Lists all topics subscribed by this app.
    ///
    /// NOTE: Dapr runtime will call this method to get
    /// the list of topics the app wants to subscribe to.
    /// In this example, the app is subscribing to topic `A`.
    async fn list_topic_subscriptions(
        &self,
        _request: Request<()>,
    ) -> Result<Response<ListTopicSubscriptionsResponse>, Status> {
        let topic = "A".to_string();
        let pubsub_name = "pubsub".to_string();

        let list_subscriptions = ListTopicSubscriptionsResponse::topic(pubsub_name, topic);

        Ok(Response::new(list_subscriptions))
    }

    /// Subscribes events from Pubsub.
    async fn on_topic_event(
        &self,
        request: Request<TopicEventRequest>,
    ) -> Result<Response<TopicEventResponse>, Status> {
        let r = request.into_inner();
        let data = &r.data;
        let data_content_type = &r.data_content_type;

        let message = String::from_utf8_lossy(&data);
        println!("Message: {}", &message);
        println!("Content-Type: {}", &data_content_type);

        Ok(Response::new(TopicEventResponse::default()))
    }

    /// Lists all input bindings subscribed by this app.
    async fn list_input_bindings(
        &self,
        _request: Request<()>,
    ) -> Result<Response<ListInputBindingsResponse>, Status> {
        Ok(Response::new(ListInputBindingsResponse::default()))
    }

    /// Listens events from the input bindings.
    async fn on_binding_event(
        &self,
        _request: Request<BindingEventRequest>,
    ) -> Result<Response<BindingEventResponse>, Status> {
        Ok(Response::new(BindingEventResponse::default()))
    }
}

pub async  fn init_dapr1() {

    
    let addr = "[::]:50051".parse().unwrap();

    let callback_service = AppCallbackService::default();

    println!("AppCallback server listening on: {}", addr);

    // Create a gRPC server with the callback_service.
    Server::builder()
        .add_service(AppCallbackServer::new(callback_service))
        .serve(addr)
         .await;
}

// #[tokio::main]
// async fn main() -> Result<(), Box<dyn std::error::Error>> {
//     let addr = "[::]:50051".parse().unwrap();

//     let callback_service = AppCallbackService::default();

//     println!("AppCallback server listening on: {}", addr);

//     // Create a gRPC server with the callback_service.
//     Server::builder()
//         .add_service(AppCallbackServer::new(callback_service))
//         .serve(addr)
//         .await?;

//     Ok(())
// }

==> ddd_dapr-0.1.8.crate: ddd_dapr-0.1.8/src/dapr/subscriber.rs <==
/*
 * @Author: tzw
 * @Date: 2021-11-09 02:01:16
 * @LastEditors: tzw
 * @LastEditTime: 2021-11-22 00:48:31
 */
use tonic::*;

use dapr::{
    appcallback::*,
    dapr::dapr::proto::runtime::v1::app_callback_server::{AppCallback, AppCallbackServer},
};

#[derive(Default)]
pub struct AppCallbackService {}

#[tonic::async_trait]
impl AppCallback for AppCallbackService {
    /// Invokes service method with InvokeRequest.
    async fn on_invoke(
        &self,
        _request: Request<InvokeRequest>,
    ) -> Result<Response<InvokeResponse>, Status> {
        Ok(Response::new(InvokeResponse::default()))
    }

    /// Lists all topics subscribed by this app.
    ///
    /// NOTE: Dapr runtime will call this method to get
    /// the list of topics the app wants to subscribe to.
    /// In this example, the app is subscribing to topic `A`.
    async fn list_topic_subscriptions(
        &self,
        _request: Request<()>,
    ) -> Result<Response<ListTopicSubscriptionsResponse>, Status> {
        let topic = "topicA".to_string();
        let pubsub_name = "messagebus".to_string();

        let topic1 = "topicB".to_string();
        let pubsub_name1 = "messagebus".to_string();
        let topic2 = "topicC".to_string();
        let pubsub_name2 = "messagebus".to_string();
        
        let topic_sub=TopicSubscription::new(topic, pubsub_name,None);
        let topic_sub1=TopicSubscription::new(topic1, pubsub_name1,None);
        let topic_sub2=TopicSubscription::new(topic2, pubsub_name2,None);


        let mut topics=vec![];
        
        topics.push(topic_sub);
        topics.push(topic_sub1);
        topics.push(topic_sub2);

        // let list_subscriptions = ListTopicSubscriptionsResponse::topic(pubsub_name, topic);
        // list_subscriptions.insert();

        let list_subscriptions= ListTopicSubscriptionsResponse{
            subscriptions: topics,
        };

        Ok(Response::new(list_subscriptions))
    }

    /// Subscribes events from Pubsub.
    async fn on_topic_event(
        &self,
        request: Request<TopicEventRequest>,
    ) -> Result<Response<TopicEventResponse>, Status> {
        let r = request.into_inner();
        let data = &r.data;
        let data_content_type = &r.data_content_type;

        let message = String::from_utf8_lossy(&data);
        println!("Message: {}", &message);
        println!("Content-Type: {}", &data_content_type);

        Ok(Response::new(TopicEventResponse::default()))
    }

    /// Lists all input bindings subscribed by this app.
    async fn list_input_bindings(
        &self,
        _request: Request<()>,
    ) -> Result<Response<ListInputBindingsResponse>, Status> {
        Ok(Response::new(ListInputBindingsResponse::default()))
    }

    /// Listens events from the input bindings.
    async fn on_binding_event(
        &self,
        _request: Request<BindingEventRequest>,
    ) -> Result<Response<BindingEventResponse>, Status> {
        Ok(Response::new(BindingEventResponse::default()))
    }
}

// pub async  fn init_dapr1() {

    
//     let addr = "[::]:50051".parse().unwrap();

//     let callback_service = AppCallbackService::default();

//     println!("AppCallback server listening on: {}", addr);

//     // Create a gRPC server with the callback_service.
//     Server::builder()
//         .add_service(AppCallbackServer::new(callback_service))
//         .serve(addr)
//          .await;
// }

// #[tokio::main]
// async fn main() -> Result<(), Box<dyn std::error::Error>> {
//     let addr = "[::]:50051".parse().unwrap();

//     let callback_service = AppCallbackService::default();

//     println!("AppCallback server listening on: {}", addr);

//     // Create a gRPC server with the callback_service.
//     Server::builder()
//         .add_service(AppCallbackServer::new(callback_service))
//         .serve(addr)
//         .await?;

//     Ok(())
// }
